pub enum ObjectsOrLinks<'a> {
    Single(ObjectOrLink<'a>),
    Multiple(Vec<ObjectOrLink<'a>>),
}
One or more ObjectOrLinks.

Variants

Single(ObjectOrLink<'a>)

Multiple(Vec<ObjectOrLink<'a>>)

Implementations

Makes an ObjectOrLinks::Single that contains the given Link.

Returns true if this either represents an Object with the given id, or contains an Object that has the given id.

Recursively calls ObjectOrLink::compact for all the inner values of this object.

Recursively runs the given function f for each Link contained in this.

Recursively runs the given function f for each Link contained in this, with mutable access to the specific ObjectOrLink.