Struct notedealer::activitypub::Date
source · [−]pub struct Date(pub OffsetDateTime);Expand description
A serialization-wise transparent struct for holding date times, just to specify that it should serialize and deserialize to and from RFC 3339 dates.
Tuple Fields
0: OffsetDateTimeTrait Implementations
sourceimpl<'de> Deserialize<'de> for Date
impl<'de> Deserialize<'de> for Date
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more