Type Definition notedealer::activitypub::Link

source · []
pub type Link<'a> = Cow<'a, str>;
A string representing a resource or other relevant information. These can be URLs, but sometimes just specific strings as defined in the Activity Vocabulary, such as “Follow” (which refers to the Follow activity).