Type Definition notedealer::activitypub::StringProp
source · [−]Expand description
A string used as the type for Object properties that do not have further
meaning aside from just being a string as far as these types go.