Enum notedealer::activitypub::ObjectsOrLinks
source · [−]pub enum ObjectsOrLinks<'a> {
Single(ObjectOrLink<'a>),
Multiple(Vec<ObjectOrLink<'a>>),
}Expand description
One or more ObjectOrLinks.
Variants
Single(ObjectOrLink<'a>)
Multiple(Vec<ObjectOrLink<'a>>)
Implementations
sourceimpl<'a> ObjectsOrLinks<'a>
impl<'a> ObjectsOrLinks<'a>
sourcepub fn link(link: Cow<'_, str>) -> ObjectsOrLinks<'_>
pub fn link(link: Cow<'_, str>) -> ObjectsOrLinks<'_>
Makes an ObjectOrLinks::Single that contains the given Link.
sourcepub fn has_id(&self, id: &str) -> bool
pub fn has_id(&self, id: &str) -> bool
Returns true if this either represents an Object with the given id, or contains an Object that has the given id.
sourcepub fn compact(&mut self)
pub fn compact(&mut self)
Recursively calls ObjectOrLink::compact for all the inner values of
this object.
sourcepub fn for_links<F: FnMut(&Cow<'a, str>)>(&self, f: F)
pub fn for_links<F: FnMut(&Cow<'a, str>)>(&self, f: F)
Recursively runs the given function f for each Link contained in
this.
sourcepub fn for_objects_or_links_mut<F: FnMut(&mut ObjectOrLink<'_>)>(&mut self, f: F)
pub fn for_objects_or_links_mut<F: FnMut(&mut ObjectOrLink<'_>)>(&mut self, f: F)
Recursively runs the given function f for each Link contained in
this, with mutable access to the specific ObjectOrLink.